==> haskell-hedgehog-classes-0.2.5.4-178-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hedgehog-classes
version:              0.2.5.4
visibility:           public
id:                   hedgehog-classes-0.2.5.4-7t6I5mGBzjWF90D0dxKBL6
key:                  hedgehog-classes-0.2.5.4-7t6I5mGBzjWF90D0dxKBL6
license:              BSD-3-Clause
copyright:            2020 chessai
maintainer:           chessai1996@gmail.com
author:               chessai
homepage:             https://github.com/hedgehogqa/haskell-hedgehog-classes
synopsis:             Hedgehog will eat your typeclass bugs
description:
    This library provides Hedgehog properties to ensure
    that typeclass instances adhere to the set of laws
    that they are supposed to. There are other libraries
    that do similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing any
    new typeclasses that the user needs to learn, and otherwise minimal
    API overhead.

    This library is directly inspired by `quickcheck-classes`.

category:             Testing
abi:                  a4108b3cbd0586a30467b5c957a24306
exposed:              True
exposed-modules:      Hedgehog.Classes
hidden-modules:
    Hedgehog.Classes.Alternative Hedgehog.Classes.Applicative
    Hedgehog.Classes.Arrow Hedgehog.Classes.Bifoldable
    Hedgehog.Classes.Bifunctor Hedgehog.Classes.Binary
    Hedgehog.Classes.Bitraversable Hedgehog.Classes.Bits
    Hedgehog.Classes.Category Hedgehog.Classes.Common
    Hedgehog.Classes.Common.ApTrans Hedgehog.Classes.Common.Bottom
    Hedgehog.Classes.Common.Compat Hedgehog.Classes.Common.Equation
    Hedgehog.Classes.Common.Func Hedgehog.Classes.Common.Gen
    Hedgehog.Classes.Common.IO Hedgehog.Classes.Common.Laws
    Hedgehog.Classes.Common.Property Hedgehog.Classes.Common.PP
    Hedgehog.Classes.Comonad Hedgehog.Classes.Contravariant
    Hedgehog.Classes.Enum Hedgehog.Classes.Eq Hedgehog.Classes.Foldable
    Hedgehog.Classes.Functor Hedgehog.Classes.Generic
    Hedgehog.Classes.Integral Hedgehog.Classes.Json
    Hedgehog.Classes.Monad Hedgehog.Classes.MonadIO
    Hedgehog.Classes.MonadPlus Hedgehog.Classes.MonadZip
    Hedgehog.Classes.Monoid Hedgehog.Classes.MVector
    Hedgehog.Classes.Ord Hedgehog.Classes.Prim
    Hedgehog.Classes.Semigroup Hedgehog.Classes.Semiring
    Hedgehog.Classes.Show Hedgehog.Classes.ShowRead
    Hedgehog.Classes.Storable Hedgehog.Classes.Traversable

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hedgehog-classes-0.2.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hedgehog-classes-0.2.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hedgehog-classes-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog-classes
hs-libraries:         HShedgehog-classes-0.2.5.4-7t6I5mGBzjWF90D0dxKBL6
depends:
    aeson-2.1.2.1-AuEsVg6Hhe2CPhaLp40FYe base-4.17.2.1 binary-0.8.9.1
    comonad-5.0.9-4t45Iulz3LJ4TodX4DUQfV containers-0.6.7
    hedgehog-1.4-3yTFEG9U8uL5UU3UJ2HLud
    pretty-show-1.10-Ey6CADemQl3EFi7OIHqHDp
    primitive-0.9.1.0-C8cd7b9dKvqDzbVOzdbvUJ
    semirings-0.7-FWrhG7szVjJ5veu0NoU5vB
    silently-1.2.5.4-9u7UVppGqLDJYp1Db2hbZU transformers-0.5.6.2
    vector-0.13.2.0-6oLw41loWTIuQEg8iaHmr
    wl-pprint-annotated-0.1.0.1-J4oWbOZaHnHLrZn8uPrSA4

haddock-interfaces:
    /usr/share/doc/haskell-hedgehog-classes/html/hedgehog-classes.haddock

haddock-html:         /usr/share/doc/haskell-hedgehog-classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hedgehog-classes-0.2.5.4-179-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hedgehog-classes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hedgehog-classes
version:              0.2.5.4
visibility:           public
id:                   hedgehog-classes-0.2.5.4-EKRBKFAtOQC1Zd3FynlVqU
key:                  hedgehog-classes-0.2.5.4-EKRBKFAtOQC1Zd3FynlVqU
license:              BSD-3-Clause
copyright:            2020 chessai
maintainer:           chessai1996@gmail.com
author:               chessai
homepage:             https://github.com/hedgehogqa/haskell-hedgehog-classes
synopsis:             Hedgehog will eat your typeclass bugs
description:
    This library provides Hedgehog properties to ensure
    that typeclass instances adhere to the set of laws
    that they are supposed to. There are other libraries
    that do similar things, such as `genvalidity-hspec` and `checkers`.
    This library differs from other solutions by not introducing any
    new typeclasses that the user needs to learn, and otherwise minimal
    API overhead.

    This library is directly inspired by `quickcheck-classes`.

category:             Testing
abi:                  a19c1ed8207fdd0cbd114f9113d29d3e
exposed:              True
exposed-modules:      Hedgehog.Classes
hidden-modules:
    Hedgehog.Classes.Alternative Hedgehog.Classes.Applicative
    Hedgehog.Classes.Arrow Hedgehog.Classes.Bifoldable
    Hedgehog.Classes.Bifunctor Hedgehog.Classes.Binary
    Hedgehog.Classes.Bitraversable Hedgehog.Classes.Bits
    Hedgehog.Classes.Category Hedgehog.Classes.Common
    Hedgehog.Classes.Common.ApTrans Hedgehog.Classes.Common.Bottom
    Hedgehog.Classes.Common.Compat Hedgehog.Classes.Common.Equation
    Hedgehog.Classes.Common.Func Hedgehog.Classes.Common.Gen
    Hedgehog.Classes.Common.IO Hedgehog.Classes.Common.Laws
    Hedgehog.Classes.Common.Property Hedgehog.Classes.Common.PP
    Hedgehog.Classes.Comonad Hedgehog.Classes.Contravariant
    Hedgehog.Classes.Enum Hedgehog.Classes.Eq Hedgehog.Classes.Foldable
    Hedgehog.Classes.Functor Hedgehog.Classes.Generic
    Hedgehog.Classes.Integral Hedgehog.Classes.Json
    Hedgehog.Classes.Monad Hedgehog.Classes.MonadIO
    Hedgehog.Classes.MonadPlus Hedgehog.Classes.MonadZip
    Hedgehog.Classes.Monoid Hedgehog.Classes.MVector
    Hedgehog.Classes.Ord Hedgehog.Classes.Prim
    Hedgehog.Classes.Semigroup Hedgehog.Classes.Semiring
    Hedgehog.Classes.Show Hedgehog.Classes.ShowRead
    Hedgehog.Classes.Storable Hedgehog.Classes.Traversable

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hedgehog-classes-0.2.5.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hedgehog-classes-0.2.5.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hedgehog-classes-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hedgehog-classes
hs-libraries:         HShedgehog-classes-0.2.5.4-EKRBKFAtOQC1Zd3FynlVqU
depends:
    aeson-2.1.2.1-6ANjbGmrSDg8K6hz3VmYXP base-4.17.2.1 binary-0.8.9.1
    comonad-5.0.9-Ar7cnVEb1Pi60zh00XTpgG containers-0.6.7
    hedgehog-1.4-iBMcUUmuliAsUv0Gb5Uoq
    pretty-show-1.10-Ey6CADemQl3EFi7OIHqHDp
    primitive-0.9.1.0-D2Xl5aBZhziHIyHGKnXxcR
    semirings-0.7-FgZ9YXsTuCRBZeyjighfnd
    silently-1.2.5.4-9u7UVppGqLDJYp1Db2hbZU transformers-0.5.6.2
    vector-0.13.2.0-ESntcdl2teUG0zU6GNugJH
    wl-pprint-annotated-0.1.0.1-KtenGtuj8T3LA8V6yvbeKc

haddock-interfaces:
    /usr/share/doc/haskell-hedgehog-classes/html/hedgehog-classes.haddock

haddock-html:         /usr/share/doc/haskell-hedgehog-classes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
